# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: market/market.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'market/market.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13market/market.proto\x12\x06market\x1a\x1fgoogle/protobuf/timestamp.proto\"o\n\x05HLOCV\x12\x12\n\x04High\x18\x01 \x01(\x01R\x04high\x12\x10\n\x03Low\x18\x02 \x01(\x01R\x03low\x12\x14\n\x05\x43lose\x18\x03 \x01(\x01R\x05\x63lose\x12\x12\n\x04Open\x18\x04 \x01(\x01R\x04open\x12\x16\n\x06Volume\x18\x05 \x01(\x01R\x06volume\"2\n\x0bProductInfo\x12#\n\x05Price\x18\x01 \x01(\x0b\x32\r.market.HLOCVR\x05price\"\x87\x02\n\x15GetProductInfoRequest\x12\x16\n\x06Ticker\x18\x01 \x01(\tR\x06ticker\x12\x14\n\x05Range\x18\x02 \x01(\tR\x05range\x12\x1a\n\x08Interval\x18\x03 \x01(\tR\x08interval\x12\x1c\n\tIndicator\x18\x04 \x01(\tR\tindicator\x12&\n\x06Source\x18\x05 \x01(\x0e\x32\x0e.market.SourceR\x06source\x12\x30\n\x05Start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05start\x12,\n\x03\x45nd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03\x65nd\"S\n\x16GetProductInfoResponse\x12#\n\x05Quote\x18\x01 \x03(\x0b\x32\r.market.QuoteR\x05quote\x12\x14\n\x05\x43ount\x18\x02 \x01(\x05R\x05\x63ount\"S\n\x13SearchTickerRequest\x12\x14\n\x05Query\x18\x01 \x01(\tR\x05query\x12&\n\x06Source\x18\x02 \x01(\x0e\x32\x0e.market.SourceR\x06source\"@\n\x14SearchTickerResponse\x12(\n\x07Tickers\x18\x01 \x03(\x0b\x32\x0e.market.TickerR\x07tickers\"4\n\x06Ticker\x12\x16\n\x06Symbol\x18\x01 \x01(\tR\x06symbol\x12\x12\n\x04Name\x18\x02 \x01(\tR\x04name\"y\n\x05Quote\x12\x38\n\tTimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x36\n\x0bProductInfo\x18\x02 \x01(\x0b\x32\x13.market.ProductInfoR\x0cproduct_info\"\x8e\x01\n\x07Monitor\x12\x0e\n\x02Id\x18\x01 \x01(\tR\x02id\x12\x14\n\x05Price\x18\x02 \x01(\x01R\x05price\x12*\n\x07\x43ompare\x18\x03 \x01(\x0e\x32\x10.market.EquationR\x07\x63ompare\x12\x31\n\x06Status\x18\x04 \x01(\x0e\x32\x13.market.AlertStatusR\x0c\x61lert_status\"5\n\x08Monitors\x12)\n\x07Monitor\x18\x01 \x03(\x0b\x32\x0f.market.MonitorR\x07monitor\"\x97\x01\n\x17GetMonitorStatusRequest\x12=\n\x04List\x18\x01 \x03(\x0b\x32).market.GetMonitorStatusRequest.ListEntryR\x04list\x1a=\n\tListEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.market.Monitors:\x02\x38\x01\"\xd3\x01\n\x18GetMonitorStatusResponse\x12>\n\x04List\x18\x01 \x03(\x0b\x32*.market.GetMonitorStatusResponse.ListEntryR\x04list\x12\x38\n\tTimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a=\n\tListEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.market.Monitors:\x02\x38\x01*6\n\x06Source\x12\x11\n\rUnknwonSource\x10\x00\x12\x0c\n\x08YFinance\x10\x01\x12\x0b\n\x07\x42inance\x10\x02*&\n\x08\x45quation\x12\x0c\n\x08MoreThan\x10\x00\x12\x0c\n\x08LessThan\x10\x01*\"\n\x0b\x41lertStatus\x12\x0b\n\x07Pending\x10\x00\x12\x06\n\x02OK\x10\x01\x32\x88\x02\n\rMarketService\x12Q\n\x0eGetProductInfo\x12\x1d.market.GetProductInfoRequest\x1a\x1e.market.GetProductInfoResponse\"\x00\x12K\n\x0cSearchTicker\x12\x1b.market.SearchTickerRequest\x1a\x1c.market.SearchTickerResponse\"\x00\x12W\n\x10GetMonitorStatus\x12\x1f.market.GetMonitorStatusRequest\x1a .market.GetMonitorStatusResponse\"\x00\x62\x08\x65\x64itionsp\xe8\x07')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'market.market_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETMONITORSTATUSREQUEST_LISTENTRY']._loaded_options = None
  _globals['_GETMONITORSTATUSREQUEST_LISTENTRY']._serialized_options = b'8\001'
  _globals['_GETMONITORSTATUSRESPONSE_LISTENTRY']._loaded_options = None
  _globals['_GETMONITORSTATUSRESPONSE_LISTENTRY']._serialized_options = b'8\001'
  _globals['_SOURCE']._serialized_start=1476
  _globals['_SOURCE']._serialized_end=1530
  _globals['_EQUATION']._serialized_start=1532
  _globals['_EQUATION']._serialized_end=1570
  _globals['_ALERTSTATUS']._serialized_start=1572
  _globals['_ALERTSTATUS']._serialized_end=1606
  _globals['_HLOCV']._serialized_start=64
  _globals['_HLOCV']._serialized_end=175
  _globals['_PRODUCTINFO']._serialized_start=177
  _globals['_PRODUCTINFO']._serialized_end=227
  _globals['_GETPRODUCTINFOREQUEST']._serialized_start=230
  _globals['_GETPRODUCTINFOREQUEST']._serialized_end=493
  _globals['_GETPRODUCTINFORESPONSE']._serialized_start=495
  _globals['_GETPRODUCTINFORESPONSE']._serialized_end=578
  _globals['_SEARCHTICKERREQUEST']._serialized_start=580
  _globals['_SEARCHTICKERREQUEST']._serialized_end=663
  _globals['_SEARCHTICKERRESPONSE']._serialized_start=665
  _globals['_SEARCHTICKERRESPONSE']._serialized_end=729
  _globals['_TICKER']._serialized_start=731
  _globals['_TICKER']._serialized_end=783
  _globals['_QUOTE']._serialized_start=785
  _globals['_QUOTE']._serialized_end=906
  _globals['_MONITOR']._serialized_start=909
  _globals['_MONITOR']._serialized_end=1051
  _globals['_MONITORS']._serialized_start=1053
  _globals['_MONITORS']._serialized_end=1106
  _globals['_GETMONITORSTATUSREQUEST']._serialized_start=1109
  _globals['_GETMONITORSTATUSREQUEST']._serialized_end=1260
  _globals['_GETMONITORSTATUSREQUEST_LISTENTRY']._serialized_start=1199
  _globals['_GETMONITORSTATUSREQUEST_LISTENTRY']._serialized_end=1260
  _globals['_GETMONITORSTATUSRESPONSE']._serialized_start=1263
  _globals['_GETMONITORSTATUSRESPONSE']._serialized_end=1474
  _globals['_GETMONITORSTATUSRESPONSE_LISTENTRY']._serialized_start=1199
  _globals['_GETMONITORSTATUSRESPONSE_LISTENTRY']._serialized_end=1260
  _globals['_MARKETSERVICE']._serialized_start=1609
  _globals['_MARKETSERVICE']._serialized_end=1873
# @@protoc_insertion_point(module_scope)
