edition = "2023";

package broker;

enum BrokerOpt {
    UnknownBroker = 0;
    Binance = 1;
    Tokocrypto = 2;
    OKX = 3;
    Coinbase = 4;
    Cexio = 5;
}

message BrokerCredential {
    // ClientName represents name of client credential.
    string ClientName = 1 [json_name="label"];
    // ClientName represents api key of client credential.
    string ClientId = 2 [json_name="client_id"];
    // ClientName represents api secret of client credential.
    string ClientSecret = 3 [json_name="client_secret"];
    // Broker represents credential's provider.
    BrokerOpt Broker = 4 [json_name="broker"];
}
