# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc
import warnings

from . import trade_pb2 as trade_dot_trade__pb2

GRPC_GENERATED_VERSION = "1.76.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(
        GRPC_VERSION, GRPC_GENERATED_VERSION
    )
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + " but the generated code in trade/trade_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class TradeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ExecuteTrade = channel.unary_unary(
            "/trade.TradeService/ExecuteTrade",
            request_serializer=trade_dot_trade__pb2.ExecuteTradeRequest.SerializeToString,
            response_deserializer=trade_dot_trade__pb2.Trade.FromString,
            _registered_method=True,
        )


class TradeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ExecuteTrade(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TradeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ExecuteTrade": grpc.unary_unary_rpc_method_handler(
            servicer.ExecuteTrade,
            request_deserializer=trade_dot_trade__pb2.ExecuteTradeRequest.FromString,
            response_serializer=trade_dot_trade__pb2.Trade.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "trade.TradeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("trade.TradeService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class TradeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ExecuteTrade(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/trade.TradeService/ExecuteTrade",
            trade_dot_trade__pb2.ExecuteTradeRequest.SerializeToString,
            trade_dot_trade__pb2.Trade.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
