# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc
import warnings

from . import market_pb2 as market_dot_market__pb2

GRPC_GENERATED_VERSION = "1.76.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(
        GRPC_VERSION, GRPC_GENERATED_VERSION
    )
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + " but the generated code in market/market_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class MarketServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetProductInfo = channel.unary_unary(
            "/market.MarketService/GetProductInfo",
            request_serializer=market_dot_market__pb2.GetProductInfoRequest.SerializeToString,
            response_deserializer=market_dot_market__pb2.GetProductInfoResponse.FromString,
            _registered_method=True,
        )
        self.SearchTicker = channel.unary_unary(
            "/market.MarketService/SearchTicker",
            request_serializer=market_dot_market__pb2.SearchTickerRequest.SerializeToString,
            response_deserializer=market_dot_market__pb2.SearchTickerResponse.FromString,
            _registered_method=True,
        )
        self.GetMonitorStatus = channel.unary_unary(
            "/market.MarketService/GetMonitorStatus",
            request_serializer=market_dot_market__pb2.GetMonitorStatusRequest.SerializeToString,
            response_deserializer=market_dot_market__pb2.GetMonitorStatusResponse.FromString,
            _registered_method=True,
        )


class MarketServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetProductInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SearchTicker(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetMonitorStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_MarketServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetProductInfo": grpc.unary_unary_rpc_method_handler(
            servicer.GetProductInfo,
            request_deserializer=market_dot_market__pb2.GetProductInfoRequest.FromString,
            response_serializer=market_dot_market__pb2.GetProductInfoResponse.SerializeToString,
        ),
        "SearchTicker": grpc.unary_unary_rpc_method_handler(
            servicer.SearchTicker,
            request_deserializer=market_dot_market__pb2.SearchTickerRequest.FromString,
            response_serializer=market_dot_market__pb2.SearchTickerResponse.SerializeToString,
        ),
        "GetMonitorStatus": grpc.unary_unary_rpc_method_handler(
            servicer.GetMonitorStatus,
            request_deserializer=market_dot_market__pb2.GetMonitorStatusRequest.FromString,
            response_serializer=market_dot_market__pb2.GetMonitorStatusResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "market.MarketService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("market.MarketService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class MarketService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetProductInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/market.MarketService/GetProductInfo",
            market_dot_market__pb2.GetProductInfoRequest.SerializeToString,
            market_dot_market__pb2.GetProductInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def SearchTicker(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/market.MarketService/SearchTicker",
            market_dot_market__pb2.SearchTickerRequest.SerializeToString,
            market_dot_market__pb2.SearchTickerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetMonitorStatus(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/market.MarketService/GetMonitorStatus",
            market_dot_market__pb2.GetMonitorStatusRequest.SerializeToString,
            market_dot_market__pb2.GetMonitorStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
