# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: trade/trade.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "trade/trade.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..model import model_pb2 as model_dot_model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11trade/trade.proto\x12\x05trade\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11model/model.proto"~\n\x13\x45xecuteTradeRequest\x12\x1f\n\x04Task\x18\x01 \x01(\x0b\x32\x0b.model.TaskR\x04task\x12*\n\x06\x41\x63tion\x18\x02 \x01(\x0e\x32\x12.trade.TradeActionR\x06\x61\x63tion\x12\x1a\n\x08Quantity\x18\x03 \x01(\x01R\x08quantity"\x8d\x02\n\x05Trade\x12\x19\n\x07TradeId\x18\x01 \x01(\tR\x08trade_id\x12\x1f\n\x04Task\x18\x02 \x01(\x0b\x32\x0b.model.TaskR\x04task\x12\x16\n\x06Status\x18\x03 \x01(\tR\x06status\x12*\n\x06\x41\x63tion\x18\x04 \x01(\x0e\x32\x12.trade.TradeActionR\x06\x61\x63tion\x12\x38\n\tTimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x1a\n\x08Quantity\x18\x06 \x01(\x01R\x08quantity\x12\x14\n\x05Price\x18\x07 \x01(\x01R\x05price\x12\x18\n\x07\x44\x65tails\x18\x08 \x01(\tR\x07\x64\x65tails*5\n\x0bTradeAction\x12\x11\n\rUnknownAction\x10\x00\x12\x08\n\x04Long\x10\x01\x12\t\n\x05Short\x10\x02\x32J\n\x0cTradeService\x12:\n\x0c\x45xecuteTrade\x12\x1a.trade.ExecuteTradeRequest\x1a\x0c.trade.Trade"\x00\x62\x08\x65\x64itionsp\xe8\x07'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "trade.trade_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_TRADEACTION"]._serialized_start = 480
    _globals["_TRADEACTION"]._serialized_end = 533
    _globals["_EXECUTETRADEREQUEST"]._serialized_start = 80
    _globals["_EXECUTETRADEREQUEST"]._serialized_end = 206
    _globals["_TRADE"]._serialized_start = 209
    _globals["_TRADE"]._serialized_end = 478
    _globals["_TRADESERVICE"]._serialized_start = 535
    _globals["_TRADESERVICE"]._serialized_end = 609
# @@protoc_insertion_point(module_scope)
