edition = "2023";

package amount;

message Amount {
    // Cur determines currency being used.
    string Cur = 1 [json_name="cur"];
    // Num determines number of amount being used.
    string Num = 2 [json_name="num"];
    // Perf determines performance of amount compared to previous period.
    string Perf = 3 [json_name="perf"];
}
