# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: broker/broker.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'broker/broker.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x62roker/broker.proto\x12\x06\x62roker\"\x9a\x01\n\x10\x42rokerCredential\x12\x19\n\nClientName\x18\x01 \x01(\tR\x05label\x12\x1b\n\x08\x43lientId\x18\x02 \x01(\tR\tclient_id\x12#\n\x0c\x43lientSecret\x18\x03 \x01(\tR\rclient_secret\x12)\n\x06\x42roker\x18\x04 \x01(\x0e\x32\x11.broker.BrokerOptR\x06\x62roker*]\n\tBrokerOpt\x12\x11\n\rUnknownBroker\x10\x00\x12\x0b\n\x07\x42inance\x10\x01\x12\x0e\n\nTokocrypto\x10\x02\x12\x07\n\x03OKX\x10\x03\x12\x0c\n\x08\x43oinbase\x10\x04\x12\t\n\x05\x43\x65xio\x10\x05\x62\x08\x65\x64itionsp\xe8\x07')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'broker.broker_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BROKEROPT']._serialized_start=188
  _globals['_BROKEROPT']._serialized_end=281
  _globals['_BROKERCREDENTIAL']._serialized_start=32
  _globals['_BROKERCREDENTIAL']._serialized_end=186
# @@protoc_insertion_point(module_scope)
