# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: statistic/statistic.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "statistic/statistic.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..types.amount import amount_pb2 as types_dot_amount_dot_amount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19statistic/statistic.proto\x12\tstatistic\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19types/amount/amount.proto"\xb2\x03\n\tStatistic\x12(\n\x07\x43\x61pital\x18\x01 \x01(\x0b\x32\x0e.amount.AmountR\x07\x63\x61pital\x12-\n\tNetProfit\x18\x02 \x01(\x0b\x32\x0e.amount.AmountR\nnet_profit\x12-\n\x11PercentProfitable\x18\x03 \x01(\tR\x12percent_profitable\x12K\n\x11TotalClosedTrades\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13total_closed_trades\x12M\n\x12TotalWinningTrades\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14total_winning_trades\x12\x39\n\x0fMaximumDrawdown\x18\x06 \x01(\x0b\x32\x0e.amount.AmountR\x10maximum_drawdown\x12\x19\n\x07WinRate\x18\x07 \x01(\tR\x08win_rate\x12+\n\x07\x44\x65tails\x18\x08 \x03(\x0b\x32\x11.statistic.TradesR\x07\x64\x65tails"H\n\x06Trades\x12\x14\n\x05Label\x18\x01 \x01(\tR\x05label\x12(\n\x06Trades\x18\x02 \x03(\x0b\x32\x10.statistic.TradeR\x06trades"\xde\x01\n\x05Trade\x12(\n\x07\x43\x61pital\x18\x01 \x01(\x0b\x32\x0e.amount.AmountR\x07\x63\x61pital\x12\x33\n\x0cOpenPosition\x18\x02 \x01(\x0b\x32\x0e.amount.AmountR\ropen_position\x12\x35\n\rClosePosition\x18\x03 \x01(\x0b\x32\x0e.amount.AmountR\x0e\x63lose_position\x12-\n\tTradeType\x18\x04 \x01(\x0e\x32\x14.statistic.TradeTypeR\x04type\x12\x10\n\x03PnL\x18\x05 \x01(\tR\x03pnl*6\n\tTradeType\x12\x14\n\x10UnknownTradeType\x10\x00\x12\x08\n\x04Long\x10\x01\x12\t\n\x05Short\x10\x02*?\n\tTimeRange\x12\x14\n\x10UnknownTimeRange\x10\x00\x12\x07\n\x03\x44\x61y\x10\x01\x12\x08\n\x04Week\x10\x02\x12\t\n\x05Month\x10\x03\x42\x32Z0github.com/michaelahli/sabot/proto/api/statisticb\x08\x65\x64itionsp\xe8\x07'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "statistic.statistic_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z0github.com/michaelahli/sabot/proto/api/statistic"
    _globals["_TRADETYPE"]._serialized_start = 868
    _globals["_TRADETYPE"]._serialized_end = 922
    _globals["_TIMERANGE"]._serialized_start = 924
    _globals["_TIMERANGE"]._serialized_end = 987
    _globals["_STATISTIC"]._serialized_start = 133
    _globals["_STATISTIC"]._serialized_end = 567
    _globals["_TRADES"]._serialized_start = 569
    _globals["_TRADES"]._serialized_end = 641
    _globals["_TRADE"]._serialized_start = 644
    _globals["_TRADE"]._serialized_end = 866
# @@protoc_insertion_point(module_scope)
