# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: model/model.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "model/model.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..statistic import statistic_pb2 as statistic_dot_statistic__pb2
from ..broker import broker_pb2 as broker_dot_broker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11model/model.proto\x12\x05model\x1a\x19statistic/statistic.proto\x1a\x13\x62roker/broker.proto"\xa8\x02\n\x04Task\x12\x17\n\x06TaskId\x18\x01 \x01(\tR\x07task_id\x12"\n\x05Model\x18\x02 \x01(\x0b\x32\x0c.model.ModelR\x05model\x12\x38\n\nCredential\x18\x03 \x01(\x0b\x32\x18.broker.BrokerCredentialR\ncredential\x12\x1a\n\x08Interval\x18\x04 \x01(\tR\x08interval\x12\x16\n\x06Ticker\x18\x05 \x01(\tR\x06ticker\x12\x32\n\tStatistic\x18\x06 \x01(\x0b\x32\x14.statistic.StatisticR\tstatistic\x12)\n\x06Status\x18\x07 \x01(\x0e\x32\x11.model.TaskStatusR\x06status\x12\x16\n\x06Timing\x18\x08 \x01(\tR\x06timing"Y\n\x05Model\x12\x19\n\x07ModelId\x18\x01 \x01(\tR\x08model_id\x12\x13\n\x04Name\x18\x02 \x01(\tR\x05label\x12 \n\x0b\x44\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription*~\n\nTaskStatus\x12\x11\n\rUnknownStatus\x10\x00\x12\n\n\x06Paused\x10\x01\x12\x10\n\x0cOpenPosition\x10\x02\x12\x0e\n\nNoPosition\x10\x03\x12\x0f\n\x0bTaskPending\x10\x04\x12\x0c\n\x08TaskDone\x10\x05\x12\x10\n\x0cTaskCanceled\x10\x06\x62\x08\x65\x64itionsp\xe8\x07'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "model.model_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_TASKSTATUS"]._serialized_start = 466
    _globals["_TASKSTATUS"]._serialized_end = 592
    _globals["_TASK"]._serialized_start = 77
    _globals["_TASK"]._serialized_end = 373
    _globals["_MODEL"]._serialized_start = 375
    _globals["_MODEL"]._serialized_end = 464
# @@protoc_insertion_point(module_scope)
